
from publicaddr import google
from publicaddr import opendns
from publicaddr import cloudflare
from publicaddr import akamai

PROVIDER_GOOGLE = google
PROVIDER_OPENDNS = opendns
PROVIDER_CLOUDFLARE = cloudflare
PROVIDER_AKAMAI = akamai

IP_V4=4
IP_V6=6

PROTO_DNS=1
PROTO_HTTP=2

def getall(provider=PROVIDER_GOOGLE, ipproto=PROTO_DNS):
    """return your public ipv4 and ipv6"""
    addrs = {}
    addrs["ip4"] = provider.lookup(ipversion=IP_V4, ipproto=ipproto)
    addrs["ip6"] = provider.lookup(ipversion=IP_V6, ipproto=ipproto)
    return addrs

def get(provider=PROVIDER_GOOGLE, ipversion=IP_V4, ipproto=PROTO_DNS):
    """return your public ipv4 or ipv6"""
    return provider.lookup(ipversion=ipversion, ipproto=ipproto)



import dns.resolver

 # ns1.google.com, ns2.google.com, ns3.google.com
dns_servers = {
    "ip4": ["216.239.32.10", "216.239.34.10", "216.239.36.10"],
    "ip6": ["2001:4860:4802:32::a", "2001:4860:4802:34::a", "2001:4860:4802:36::a"],
}

def _resolv_addr(nameservers=[], qname="o-o.myaddr.google.com", rdtype="TXT" ):
    dnsresolv = dns.resolver.Resolver(configure=False)
    dnsresolv.nameservers = nameservers

    # make dns resolution
    answers = dnsresolv.resolve(qname, rdtype)
    return answers[0].strings[0].decode()

def lookup(ipversion, ipproto):
    if ipversion == 4:
        return _resolv_addr(nameservers=dns_servers["ip4"])
    if ipversion == 6:
        return _resolv_addr(nameservers=dns_servers["ip6"])



import requests

http_servers = {
    "ip4": "http://ipv4.whatismyip.akamai.com/",
    "ip6": "http://ipv6.whatismyip.akamai.com/",
}

def lookup(ipversion, ipproto):
    if ipversion == 4:
        return requests.get(http_servers["ip4"]).text.rstrip()
    if ipversion == 6:
        return requests.get(http_servers["ip6"]).text.rstrip()



import dns.resolver

# resolver1.opendns.com, resolver2.opendns.com
dns_servers = {
    "ip4": ["208.67.222.222", "208.67.220.220"],
    "ip6": ["2620:119:35::35", "2620:119:53::53"],
}

# dig myip.opendns.com @resolver1.opendns.com -6 AAAA +short
# dig myip.opendns.com @resolver1.opendns.com -4 A +short

def _resolv_addr(nameservers=[], qname="myip.opendns.com", rdtype="A"):
    dnsresolv = dns.resolver.Resolver(configure=False)
    dnsresolv.nameservers = nameservers

    # make dns resolution
    answers = dnsresolv.resolve(qname, rdtype)
    return answers[0].to_text()

def lookup(ipversion, ipproto):
    if ipversion == 4:
        return _resolv_addr(nameservers=dns_servers["ip4"], rdtype="A")
    if ipversion == 6:
        return _resolv_addr(nameservers=dns_servers["ip6"], rdtype="AAAA")



import dns.resolver

# resolver1.opendns.com, resolver2.opendns.com
dns_servers = {
    "ip4": ["1.1.1.1", "1.0.0.1"],
    "ip6": ["2606:4700:4700::1111", "2606:4700:4700::1001"],
}

# dig @2606:4700:4700::1111 whoami.cloudflare TXT CH +short
# dig @2606:4700:4700::1111 whoami.cloudflare TXT CH +short
def _resolv_addr(nameservers=[], qname="whoami.cloudflare", rdtype="TXT", rdclass="CH"  ):
    dnsresolv = dns.resolver.Resolver(configure=False)
    dnsresolv.nameservers = nameservers

    # make dns resolution
    answers = dnsresolv.resolve(qname, rdtype, rdclass)
    return answers[0].strings[0].decode()

def lookup(ipversion, ipproto):
    if ipversion == 4:
        return _resolv_addr(nameservers=dns_servers["ip4"])
    if ipversion == 6:
        return _resolv_addr(nameservers=dns_servers["ip6"])